@@ -65,7 +65,7 @@ class _ShelfBoundDeclarativeMeta(flask_sqlalchemy._BoundDeclarativeMeta):
                 if isinstance(val, Column):
                     val.name = name + "_" + col
 
-            '''tmp = cls.__dict__.copy()
+            tmp = cls.__dict__.copy()
             for col in tmp:
                 if col.startswith("__"):
                     continue
@@ -80,7 +80,7 @@ class _ShelfBoundDeclarativeMeta(flask_sqlalchemy._BoundDeclarativeMeta):
                     delattr(cls, col)
                 elif isinstance(val, InstrumentedAttribute):
                     setattr(cls, name+"_"+col, val)
-                    delattr(cls, col)'''
+                    delattr(cls, col)
 
         return DeclarativeMeta.__new__(cls, name, bases, d)
 
