@@ -12,4 +12,11 @@ class User(db.Model, flask_login.UserMixin):
 	profile = db.Column(db.Enum("Subscriber", "Contributor", "Author", "Editor", "Admin"))
 	_mail_activated = db.Column("mail_activated", db.Boolean)
 	_password_lost = db.Column("password_lost", db.Boolean)
-	_is_active = db.Column("is_active", db.Boolean)
\ No newline at end of file
+	_is_active = db.Column("is_active", db.Boolean)
+
+	def is_active(self):
+		return self._is_active
+
+	def can_admin(self):
+		cans = ("Contributor", "Author", "Editor", "Admin")
+		return self.profile and self.profile in cans
\ No newline at end of file
